# players_amp
### written in Phyton 3.8.1 by Strolch

import json

import requests


class Logout:

    # logout mainpage
    def main(server, port, header, sessionid):
        mainendpoint = "/API/Core/Logout"
        data = {'SESSIONID': sessionid}

        Rückgabe = requests.post(url=('http://' + server + ":" + port + mainendpoint), data=json.dumps(data),
                                 headers=header)
        return Rückgabe

    # logout game server instances
    def instances(server, port, header, instanceids, sessionids):
        otherendpoint_part1 = "/API/ADSModule/Servers/"
        otherendpoint_part2 = "/API/Core/Logout"

        i = 1
        Rückgabe = []
        while i < len(instanceids):
            # an game server logout loop :D
            data = {'SESSIONID': sessionids[i]}
            post = requests.post(
                url=('http://' + server + ":" + port + otherendpoint_part1 + instanceids[i] + otherendpoint_part2),
                data=json.dumps(data), headers=header)
            Rückgabe.append(post)
            i += 1
        return Rückgabe



# players_amp
### written in Phyton 3.8.1 by Strolch

import os.path
import re

from appdirs import user_config_dir

from players_amp import api_functions


def main():
    try:

        # reads settings.txt and save the data
        filename = "settings.txt"
        path = user_config_dir(appauthor="Strolch", appname="players_amp", roaming=False)
        filepath = os.path.join(path, filename)

        file = open(filepath, mode='r')
        settings = re.findall(r'"(.*?)"', file.read())
        file.close()

        server = settings[0]
        port = settings[1]
        username = settings[2]
        password = settings[3]
        header = {'Accept': 'application/json'}

        sessionid = api_functions.Login.session_id(server, port, username, password, header)
        instanceids = api_functions.GetInstances.instance_ids(server, port, header, sessionid)
        sessionids = api_functions.Login.session_ids(server, port, username, password, header, instanceids)
        usercount = api_functions.GetUpdates.usercount(server, port, header, sessionids, instanceids)

        api_functions.Logout.instances(server, port, header, instanceids, sessionids)
        api_functions.Logout.main(server, port, header, sessionid)

        return str(usercount)

    except:

        print("Unfortunately, there was an problem.")
        print("Please try it again with players_amp.debug to see the errors!")
        print("amp.debug uses no exception handling and prints more information")



# players_amp
### written in Phyton 3.8.1 by Strolch

import json

import requests


class Login:

    # Logs into the mainpage and returns its sessionid
    def session_id(server, port, username, password, header):
        mainendpoint = "/API/Core/Login"
        data = {'username': username, 'password': password, 'token': "", 'rememberMe': 'false'}

        post = (
            requests.post(url=('http://' + server + ":" + port + mainendpoint), data=json.dumps(data), headers=header))

        return (json.loads(post.content).get('sessionID'))

    # Logs into all game server instances and return the sessionids within an array
    def session_ids(server, port, username, password, header, instanceids):
        otherendpoint_part1 = "/API/ADSModule/Servers/"
        otherendpoint_part2 = "/API/Core/Login"
        data = {'username': username, 'password': password, 'token': "", 'rememberMe': 'false'}

        i = 0
        rückgabe = []
        while i < len(instanceids):
            # logs into an game server instance and saves its sessionid into the array
            post = requests.post(
                url=('http://' + server + ":" + port + otherendpoint_part1 + instanceids[i] + otherendpoint_part2),
                data=json.dumps(data), headers=header)
            post = json.loads(post.content).get('sessionID')
            rückgabe.append(post)
            i += 1

        return rückgabe



# players_amp
### written in Phyton 3.8.1 by Strolch

import json

import requests


class GetInstances:

    def instance_ids(server, port, header, sessionid):
        endpoint = "/API/ADSModule/GetInstances"
        data = {'SESSIONID': sessionid, }

        # makes an request, save the data as dict, and goes deep into it on the right level
        requestids = (
            requests.post(url=('http://' + server + ":" + port + endpoint), data=json.dumps(data), headers=header))
        requestids = json.loads(requestids.content)
        requestids = requestids.get('result')[0].get('AvailableInstances')

        # searches an suitable instanceid in loop, saves them into the array which it returns
        rückgabe = []
        i = 0
        while i < len(requestids):
            rückgabe.append(requestids[i]['InstanceID'])
            i += 1

        return rückgabe



# players_amp
### written in Phyton 3.8.1 by Strolch

import json

import requests


class GetUpdates:

    def usercount(server, port, header, sessionids, instanceids):
        otherendpoint_part1 = "/API/ADSModule/Servers/"
        otherendpoint_part2 = "/API/Core/GetUpdates"

        rückgabe = 0
        i = 1
        while i < len(instanceids):  # not really matter if instanceids sessionids
            data = {'SESSIONID': sessionids[i], }
            post = requests.post(
                url=('http://' + server + ":" + port + otherendpoint_part1 + instanceids[i] + otherendpoint_part2),
                data=json.dumps(data), headers=header)
            post = json.loads(post.content)
            rückgabe += post.get('Status').get('UserCount')
            i += 1

        return rückgabe



# players_amp
### written in Phyton 3.8.1 by Strolch

import os.path
from pathlib import Path

from appdirs import user_config_dir

global filename
filename = "settings.txt"


# if the filepath exists the function will erase it and give it to the next function to save new settings
# else the filepath not exists, the function will create the dirs, the file and give the file to the next function to save settings
def setserver():
    path = user_config_dir(appauthor="Strolch", appname="players_amp", roaming=False)
    filepath = os.path.join(path, filename)

    print(path)

    if os.path.isfile(filepath):
        print("Please write down \"ColaDose\", if you you are ready!(the old settings will be cleared)")
        if input() == "ColaDose":
            savesettings(filepath)
        else:
            print("cancelled!")
    else:
        print("preparing for the first configuration!\n")
        Path(path).mkdir(parents=True, exist_ok=True)
        savesettings(filepath)


def savesettings(filepath):
    file = open(filepath, 'w+')
    file.truncate(0)

    print("Please write down the following informations!")

    print("server:")
    file.write("server = \"" + input() + "\"\n")
    print("serverport:")
    file.write("serverport = \"" + input() + "\"\n")
    print("username:")
    file.write("username = \"" + input() + "\"\n")
    print("password:")
    file.write("password = \"" + input() + "\"\n")

    file.close()

    print("nice! It worked!")



# players_amp
### written in Phyton 3.8.1 by Strolch

import os.path
import re

from appdirs import user_config_dir

from players_amp import api_functions


def debug():
    # reads settings.txt and save the data
    filename = "settings.txt"
    path = user_config_dir(appauthor="Strolch", appname="players_amp", roaming=False)
    filepath = os.path.join(path, filename)

    file = open(filepath, mode='r')
    settings = re.findall(r'"(.*?)"', file.read())
    file.close()

    server = settings[0]
    port = settings[1]
    username = settings[2]
    password = settings[3]
    header = {'Accept': 'application/json'}

    sessionid = api_functions.Login.session_id(server, port, username, password, header)
    instanceids = api_functions.GetInstances.instance_ids(server, port, header, sessionid)
    sessionids = api_functions.Login.session_ids(server, port, username, password, header, instanceids)
    usercount = api_functions.GetUpdates.usercount(server, port, header, sessionids, instanceids)

    print("session id (Mainpage): " + sessionid)

    i = 1
    while i < len(instanceids):
        print("instance id [" + str(i) + "]: " + instanceids[i])
        i += 1

    i = 1
    while i < len(sessionids):
        print("session id [" + str(i) + "]: " + sessionids[i])
        i += 1

    logouts = api_functions.Logout.instances(server, port, header, instanceids, sessionids)
    i = 0
    while i < len(logouts):
        if (logouts[i]).content == b'null':
            print("instance " + str(i) + " - Logout successful!")
        else:
            print("Error: instance " + str(i) + " - Logout UNSUCCESSFUL!")
        i += 1

    logout = api_functions.Logout.main(server, port, header, sessionid)
    if logout.content == b'null':
        print("Mainpage - Logout successful!")
    else:
        print("Error: Mainpage - Logout UNSUCCESSFUL!")

    print("playercount: " + str(usercount))



# players_amp
### written in Phyton 3.8.1 by Strolch

from setuptools import setup

setup(
    name='players_amp',
    version='2.34',
    license='MIT',
    description='a little tool written in phyton to count all the active players on your AMP managed game server',
    author='Strolch',
    author_email='hello.circles@gmail.com',
    url="https://github.com/R0b95/player_amp",
    download_url='https://github.com/R0b95/players_amp/archive/2.0.tar.gz',
    keywords=['AMP', 'UserCount', 'ActiveUser', 'ActivePlayer'],
    packages=['players_amp', 'players_amp.api_functions'],
    entry_points="""
        [console_scripts] 
            players_amp = players_amp.main:main
            players_amp.debug = players_amp.debug:debug
            players_amp.setserver = players_amp.setserver:setserver
        """,
    install_requires="""
        appdirs
    """,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
    ],
)
